==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/zh-TW.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "管理燈箱GALLARY參數");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "管理圖庫");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "全尺寸圖片寬度");
define('MANAGE_GALLERY_FULL_HEIGHT', "全尺寸圖片高度");
define('MANAGE_GALLERY_THUMB_WIDTH', "縮略圖寬度");
define('MANAGE_GALLERY_THUMB_HEIGHT', "縮略圖高度");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "保留拇指長寬比");
define('MANAGE_GALLERY_SHOW_TITLES', "顯示標題");
define('MANAGE_GALLERY_DISABLE_SORT', "禁用排序");
define('MANAGE_GALLERY_DELETE_IMAGE', "刪除圖像");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "保存排序順序");
define('MANAGE_GALLERY_PUBLISH_MSG', "點擊“更新”發布<br />您上傳的圖片。");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "所有圖像都被調整和設置已保存。");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "有一個錯誤的調整圖像或保存設置。");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "您的圖像（S）已上載。");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "有一個錯誤上傳您的圖像（S）。");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "您要上傳的文件不是圖像。");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "您要上傳的文件過大。");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "標題已保存。");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "你確定要刪除的圖像");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "？");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "圖像已被刪除。");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "有一個錯誤刪除圖像。");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "保存參數和調整圖像大小，請稍候...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "上傳文件，請稍候...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "排序順序尚未保存。你要保存的排序順序？");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "圖像排序順序已保存。");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "有一個錯誤保存圖像排序。");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/zh-TW.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "管理燈箱GALLARY參數");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "管理圖庫");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "全尺寸圖片寬度");
define('MANAGE_GALLERY_FULL_HEIGHT', "全尺寸圖片高度");
define('MANAGE_GALLERY_THUMB_WIDTH', "縮略圖寬度");
define('MANAGE_GALLERY_THUMB_HEIGHT', "縮略圖高度");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "保留拇指長寬比");
define('MANAGE_GALLERY_SHOW_TITLES', "顯示標題");
define('MANAGE_GALLERY_DISABLE_SORT', "禁用排序");
define('MANAGE_GALLERY_DELETE_IMAGE', "刪除圖像");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "保存排序順序");
define('MANAGE_GALLERY_PUBLISH_MSG', "點擊“更新”發布<br />您上傳的圖片。");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "所有圖像都被調整和設置已保存。");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "有一個錯誤的調整圖像或保存設置。");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "您的圖像（S）已上載。");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "有一個錯誤上傳您的圖像（S）。");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "您要上傳的文件不是圖像。");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "您要上傳的文件過大。");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "標題已保存。");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "你確定要刪除的圖像");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "？");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "圖像已被刪除。");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "有一個錯誤刪除圖像。");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "保存參數和調整圖像大小，請稍候...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "上傳文件，請稍候...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "排序順序尚未保存。你要保存的排序順序？");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "圖像排序順序已保存。");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "有一個錯誤保存圖像排序。");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "您嘗試上傳的文件大於&#39;upload_max_filesize&#39;或&#39;post_max_size&#39;PHP設置。請與系統管理員聯繫以增加這些限制。");
?>
